@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:51:10
-@LastEditTime: 2022-07-19 10:50:24
+@LastEditTime: 2022-11-21 17:08:54
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,7 +11,7 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.mp_base_model import *
 from seven_cloudapp_frame.models.push_base_model import *
 from asq.initiators import query
-
+from seven_cloudapp_frame.libs.customize.baidubce_helper import *
 
 class AppExpireHandler(ClientBaseHandler):
     """
@@ -57,6 +57,47 @@ class CreateWeChatQrCodeHandler(ClientBaseHandler):
             self.write("")
 
 
+class UploadFileHandler(ClientBaseHandler):
+    """
+    :description: 上传文件
+    """
+
+    def get_async(self):
+        """
+        :description: 上传文件
+        :last_editors: HuangJianYi
+        """
+        # 上传图片到资源服务器
+        if not self.request.files:
+            return self.response_json_error("error", "未获取到文件")
+
+        file_path = BaidubceHelper.upload_file(self.request.files, context=self)
+        if not file_path:
+            return self.response_json_error("error", "上传文件失败")
+        return self.response_json_success(file_path)
+
+
+class AddWechatSubscribeHandler(ClientBaseHandler):
+    """
+    :description: 添加微信订阅次数
+    """
+    def get_async(self):
+        """
+        :description: 添加微信订阅次数
+        :param template_id：template_id
+        :param open_id：open_id
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        template_id = self.get_param("template_id")
+        open_id = self.get_param("open_id")
+        push_base_model = PushBaseModel(context=self)
+        invoke_result_data = push_base_model.add_wechat_subscribe(config.get_value("app_id"), template_id, open_id)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        return self.response_json_success()
+
+
 class GetHighPowerListHandler(ClientBaseHandler):
     """
     :description: 获取中台配置的高级权限列表
