@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2022-07-19 10:52:56
+@LastEditTime: 2022-07-26 14:22:49
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -298,11 +298,11 @@ class InviteNewUserHandler(ClientBaseHandler):
         close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else False
 
-        stat_base_model = StatBaseModel(context=self.context)
+        stat_base_model = StatBaseModel(context=self)
         if is_stat == True:
             stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"BeInvitedUserCount": 1, "BeInvitedCount": 1})
 
-        invoke_result_data = task_base_model.process_invite_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, self.request_code, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
+        invoke_result_data = task_base_model.process_invite_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if is_stat == True:
