@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-11-14 15:08:20
+@LastEditTime: 2022-11-15 17:26:33
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -126,6 +126,10 @@ class UpdateUserInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         else:
+            ref_params = {}
+            invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+            if invoke_result_data.success == False:
+                return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             return self.response_json_success("更新成功")
 
 
