@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-10-20 17:03:53
+@LastEditTime: 2022-11-18 17:42:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -46,6 +46,7 @@ class FrameBaseHandler(BaseApiHandler):
             dict_param["open_id"] = self.get_user_id()
         dict_param["nick_name"] = self.get_user_nick()
         dict_param["app_id"] = self.get_app_id()
+        dict_param["source_type"] = self._request_source_type()
         return dict_param
 
     def prepare(self):
@@ -168,6 +169,9 @@ class FrameBaseHandler(BaseApiHandler):
         :Description: 请求来源类型 0-未知 1-client(客户端) 2-server(服务端)
         :last_editors: HuangJianYi
         """
+        plat_type = config.get_value("plat_type", 1) # 平台类型 1淘宝2微信3抖音4web
+        if plat_type == 4:
+            return 1
         uri = self.request.uri
         if "/client/" in uri:
             return 1
@@ -413,7 +417,7 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         open_id = self.get_param("open_id")
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音4web
         if plat_type == 1:
             if self.get_param("source_app_id") == "":
                 test_config = config.get_value("test_config",{})
@@ -434,6 +438,37 @@ class FrameBaseHandler(BaseApiHandler):
                 user_id = self.get_param_int("user_id")
         return user_id
 
+    def get_cooke_user_id(self):
+        """
+        :description: 获取cookie中的用户信息,适用场景H5
+        :return:
+        :last_editors: HuangJianYi
+        """
+        test_config = config.get_value("test_config", {})
+        user_id = test_config.get("user_id", 0)
+        if user_id <= 0:
+            cookie_user_id = int(self.get_cookie("user_id", 0))
+            cookie_user_id_md5 = self.get_cookie("user_id_md5","")
+            check_user_id_md5 = CryptoHelper.md5_encrypt(str(cookie_user_id), config.get_value("cookie_encrypt_key", "r8C1JpyAXxrFV26V"))
+            if cookie_user_id <= 0 or cookie_user_id_md5 != check_user_id_md5:
+                user_id = 0
+            else:
+                user_id = cookie_user_id
+        return user_id
+
+    def set_cooke_user_id(self, user_id, expires_days=30):
+        """
+        :description: 设置user_id cookie
+        :param user_id: 用户标识
+        :param expires_days: 过期时间，单位天
+        :return:
+        :last_editors: HuangJianYi
+        """
+        user_id_md5 = CryptoHelper.md5_encrypt(str(user_id), config.get_value("cookie_encrypt_key", "r8C1JpyAXxrFV26V"))
+        self.set_cookie("user_id", str(user_id), expires_days=expires_days)
+        self.set_cookie("user_id_md5", user_id_md5, expires_days=expires_days)
+        self.set_cookie("user_token", UUIDHelper.get_uuid(), expires_days=expires_days)
+
     def get_source_app_id(self):
         """
         :description: 废弃使用,获取source_app_id(客户端client使用)，旧项目有用到要换成get_app_id
