@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-11-15 09:44:54
+@LastEditTime: 2022-11-23 10:50:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -34,8 +34,8 @@ class WeChatHelper:
     @classmethod
     def get_web_authorize_url(self, redirect_uri, scope="snsapi_userinfo", app_id="", state="1"):
         """
-        :description:获取网页授权链接
-        :param redirect_uri：授权后重定向的回调地址，请使用urlencode对链接进行处理
+        :description:获取网页授权链接, 注意：公众号必须是服务号并认证才可以使用网页授权
+        :param redirect_uri：授权后重定向的回调地址
         :param scope：应用授权作用域，snsapi_base （不弹出授权页面，直接跳转，只能获取用户openid），snsapi_userinfo （弹出授权页面，可通过openid拿到昵称、性别、所在地。并且，即使在未关注的情况下，只要用户授权，也能获取其信息）
         :param app_id：公众号的唯一标识
         :param state：重定向后会带上state参数，开发者可以填写a-zA-Z0-9的参数值，最多128字节
@@ -43,7 +43,7 @@ class WeChatHelper:
         :last_editors: HuangJianYi
         """
         app_id = app_id if app_id else config.get_value("app_id")
-        authorize_url = "https://open.weixin.qq.com/connect/oauth2/authorize?appid={0}&redirect_uri={1}&response_type=code&scope={2}&state={3}&connect_redirect=1#wechat_redirect".format(app_id,CodingHelper.url_encode(redirect_uri),scope,CodingHelper.url_encode(state))
+        authorize_url = "https://open.weixin.qq.com/connect/oauth2/authorize?appid={0}&redirect_uri={1}&response_type=code&scope={2}&state={3}&connect_redirect=1#wechat_redirect".format(app_id, CodingHelper.url_encode(redirect_uri), scope, CodingHelper.url_encode(state))
         return authorize_url
 
     @classmethod
@@ -81,7 +81,7 @@ class WeChatHelper:
             open_id = response_data['openid']
             access_token = response_data['access_token']
             requset_url = "https://api.weixin.qq.com/sns/userinfo"
-            response = requests.get(requset_url, params={'access_token':access_token,'openid':open_id,'lang':"zh_CN"})
+            response = requests.get(requset_url, params={'access_token': access_token, 'openid': open_id, 'lang': "zh_CN"})
             response_data = SevenHelper.json_loads(response.text)
             if response_data.__contains__("errcode") and response_data["errcode"] != 0:
                 invoke_result_data.success = False
@@ -98,7 +98,36 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def get_jsapi_ticket(self, app_id="", app_secret="", is_del=False):
+    def get_jsapi_ticket(self, app_id=""):
+        """
+        :description:获取jsapi_ticket,注意：需在公众号后台添加ip白名单，控制台去请求微信接口获取
+        :param app_id:app_id
+        :return: 返回ticket
+        :last_editors: HuangJianYi
+        """
+        app_id = app_id if app_id else config.get_value("app_id")
+
+        invoke_result_data = InvokeResultData()
+        try:
+            redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
+            redis_key = f"wechat_jsapi_ticket:{str(app_id)}"
+            jsapi_ticket = redis_init.get(redis_key)
+            if not jsapi_ticket:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "jsapi_ticket不存在"
+                return invoke_result_data
+            invoke_result_data.data = jsapi_ticket
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【get_jsapi_ticket】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    @classmethod
+    def set_jsapi_ticket(self, app_id="", app_secret="", is_del=False):
         """
         :description:获取jsapi_ticket
         :param app_id:app_id
@@ -109,6 +138,7 @@ class WeChatHelper:
         """
         app_id = app_id if app_id else config.get_value("app_id")
         app_secret = app_secret if app_secret else config.get_value("app_secret")
+
         invoke_result_data = InvokeResultData()
         for i in range(2):
             if i == 0:
@@ -127,10 +157,6 @@ class WeChatHelper:
         if is_del == True:
             redis_init.delete(redis_key)
         try:
-            jsapi_ticket = redis_init.get(redis_key)
-            if jsapi_ticket:
-                invoke_result_data.data = jsapi_ticket
-                return invoke_result_data
             requset_url = f"https://api.weixin.qq.com/cgi-bin/ticket/getticket?access_token={access_token}&type=jsapi"
             response = requests.get(requset_url)
             response_data = SevenHelper.json_loads(response.text)
@@ -143,7 +169,7 @@ class WeChatHelper:
             redis_init.set(redis_key, invoke_result_data.data, ex=3600)
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【get_jsapi_ticket】" + traceback.format_exc())
+            self.logger_error.error("【set_jsapi_ticket】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = traceback.format_exc()
@@ -159,15 +185,22 @@ class WeChatHelper:
         :return: 返回分享请求参数
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+
+        invoke_result_data = InvokeResultData()
         request_url = request_url.split('#')[0]
         timestamp = int(time.time())
-        js_ticket = self.get_jsapi_ticket(app_id, app_secret,True)
+        invoke_result_data = self.get_jsapi_ticket(app_id)
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        js_ticket = invoke_result_data.data
         noncestr = self.get_nonce_str()
         param = {'noncestr': noncestr, 'jsapi_ticket': js_ticket, 'timestamp': timestamp, 'url': request_url}
-        string_sign_temp = self.key_value_url(param)
+        string_sign_temp = self.key_value_url(param, False)
         sign = hashlib.sha1(string_sign_temp.encode("utf8")).hexdigest()
         sign_package = {'appid': app_id, 'noncestr': noncestr, 'timestamp': timestamp, 'url': request_url, 'signature': sign}
-        return sign_package
+        invoke_result_data.data = sign_package
+        return invoke_result_data
 
     @classmethod
     def code2_session(self, code, grant_type="authorization_code", app_id="", app_secret=""):
@@ -222,7 +255,46 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def get_access_token(self, app_id="", app_secret="", is_del=False, grant_type="client_credential"):
+    def get_access_token(self, app_id="", app_secret="", is_del=False, grant_type="client_credential", from_wechat_get = True):
+        """
+        :description:access_token 是微信的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。建议开发者使用中控服务器统一获取和刷新 access_token，其他业务逻辑服务器所使用的 access_token 均来自于该中控服务器，不应该各自去刷新，否则容易造成冲突，导致 access_token 覆盖而影响业务；
+        :description:注意：如果是公众号开发，需在公众号后台添加ip白名单，控制台去请求微信接口获取，小程序不用
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :param is_del:是否删除redis里的access_token
+        :param grant_type: 获取access_token 时值为 client_credential
+        :param from_wechat_get: 是否请求微信接口获取access_token并存到redis
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+
+        invoke_result_data = InvokeResultData()
+
+        try:
+            redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
+            redis_key = f"wechat_access_token:{str(app_id)}"
+            if is_del == True:
+                redis_init.delete(redis_key)
+            access_token = redis_init.get(redis_key)
+            if access_token:
+                invoke_result_data.data = access_token
+                return invoke_result_data
+            if from_wechat_get == True:
+                invoke_result_data = self.set_access_token(app_id, app_secret, is_del, grant_type)
+                if invoke_result_data.success == False:
+                    return invoke_result_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【get_access_token】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    @classmethod
+    def set_access_token(self, app_id="", app_secret="", is_del=False, grant_type="client_credential"):
         """
         :description:access_token 是微信的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。建议开发者使用中控服务器统一获取和刷新 access_token，其他业务逻辑服务器所使用的 access_token 均来自于该中控服务器，不应该各自去刷新，否则容易造成冲突，导致 access_token 覆盖而影响业务；
         :param app_id:app_id
@@ -247,10 +319,6 @@ class WeChatHelper:
         if is_del == True:
             redis_init.delete(redis_key)
         try:
-            access_token = redis_init.get(redis_key)
-            if access_token:
-                invoke_result_data.data = access_token
-                return invoke_result_data
             requset_url = 'https://api.weixin.qq.com/cgi-bin/token'
             response = requests.get(requset_url, params=param)
             response_data = SevenHelper.json_loads(response.text)
@@ -263,7 +331,7 @@ class WeChatHelper:
             redis_init.set(redis_key, invoke_result_data.data, ex=3600)
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【get_access_token】" + traceback.format_exc())
+            self.logger_error.error("【set_access_token】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = traceback.format_exc()
@@ -369,6 +437,8 @@ class WeChatHelper:
         :param page: 页面 page，例如 pages/index/index，根路径前不要填加 /，不能携带参数（参数请放在scene字段里），如果不填写这个字段，默认跳主页面
         :param scene: 最大32个可见字符，只支持数字，大小写英文以及部分特殊字符：!#$&'()*+,/:;=?@-._~，其它字符请自行编码为合法字符（因不支持%，中文无法使用 urlencode 处理，请使用其他编码方式）
         :param width: 二维码的宽度，单位 px，最小 280px，最大 1280px
+        :param app_id:app_id
+        :param app_secret:app_secret
         :return: 图片二进制 数据类型Array<byte>
         :last_editors: HuangJianYi
         """
@@ -417,12 +487,15 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def msg_sec_check(self, content, scene, open_id):
+    def msg_sec_check(self, content, scene, open_id, nickname, app_id="", app_secret=""):
         """
         :description: 文本内容安全识别(https://developers.weixin.qq.com/miniprogram/dev/OpenApiDoc/sec-center/sec-check/msgSecCheck.html)
         :param content：需检测的文本内容，文本字数的上限为2500字，需使用UTF-8编码
         :param scene：场景枚举值（1 资料；2 评论；3 论坛；4 社交日志）
         :param openid：用户的openid（用户需在近两小时访问过小程序）
+        :param nickname：用户昵称
+        :param app_id:app_id
+        :param app_secret:app_secret
         :return:
         :last_editors: HuangJianYi
         """
@@ -445,7 +518,7 @@ class WeChatHelper:
         try:
             requset_url = 'https://api.weixin.qq.com/wxa/msg_sec_check?access_token=' + access_token
             headers = {"Content-type": "application/json"}
-            param = {"content": content, "scene": scene, "openid": open_id, "version": 2}
+            param = {"content": content, "scene": scene, "openid": open_id, "nickname": nickname, "version": 2}
             response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
             response_data = SevenHelper.json_loads(response.text)
             if response_data.__contains__("errcode") and response_data["errcode"] != 0:
