@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2022-08-31 15:04:42
+@LastEditTime: 2022-11-22 14:32:04
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -407,7 +407,7 @@ class AssetBaseModel():
                     user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
-    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1):
+    def get_asset_log_list(self, app_id, act_id, asset_type=0, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1):
         """
         :description: 获取用户资产流水记录
         :param app_id：应用标识
@@ -431,12 +431,12 @@ class AssetBaseModel():
         """
         page_list = []
         total = 0
-        if not act_id or asset_type <= 0:
-            return page_list,total
-
-        condition = "act_id=%s AND asset_type=%s"
-        params = [act_id, asset_type]
 
+        condition = "act_id=%s"
+        params = [act_id]
+        if asset_type != 0:
+            condition += " AND asset_type=%s"
+            params.append(asset_type)
         if user_id != 0:
             condition += " AND user_id=%s"
             params.append(user_id)
