@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-08-24 16:21:23
+@LastEditTime: 2022-11-18 17:00:10
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -108,7 +108,7 @@ class StatBaseModel(FrameBaseModel):
             for stat_queue in stat_queue_list:
                 redis_init.rpush(f"stat_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
 
-    def get_stat_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False):
+    def get_stat_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False, orm_condition=None, orm_params=None):
         """
         :description: 报表数据列表(表格)
         :param app_id：应用标识
@@ -116,29 +116,38 @@ class StatBaseModel(FrameBaseModel):
         :param module_id：活动模块标识
         :param start_date：开始时间
         :param end_date：结束时间
-        :param order_by：排序
+        :param order_by：orm排序
         :param is_only_module：是否只取module的数据
+        :param orm_condition：orm查询条件
+        :param orm_params：orm参数数组
         :return list
         :last_editors: HuangJianYi
         """
-        condition = "app_id=%s and act_id=%s and module_id=%s"
+        report_condition = "app_id=%s and act_id=%s and module_id=%s"
         params = [app_id,act_id,module_id]
         if start_date != "":
-            condition += " and create_date>=%s"
+            report_condition += " and create_date>=%s"
             params.append(start_date)
         if end_date != "":
-            condition += " and create_date<%s"
+            report_condition += " and create_date<%s"
             params.append(end_date)
         if is_only_module == True:
-            stat_orm_list = StatOrmModel(context=self.context).get_list("act_id=%s and module_id=%s and is_show=1", order_by=order_by, params=[act_id, module_id])
+            if not orm_condition:
+                orm_condition = "act_id=%s and module_id=%s and is_show=1"
+            if not orm_params:
+                orm_params = [act_id, module_id]
         else:
-            stat_orm_list = StatOrmModel(context=self.context).get_list("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1", order_by=order_by, params=[act_id,module_id])
+            if not orm_condition:
+                orm_condition = "((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1"
+            if not orm_params:
+                orm_params = [act_id,module_id]
+        stat_orm_list = StatOrmModel(context=self.context).get_list(where=orm_condition, order_by=order_by, params=orm_params)
         if len(stat_orm_list)<=0:
             return []
         key_name_s = ','.join(["'%s'" % str(stat_orm.key_name) for stat_orm in stat_orm_list])
-        condition += f" and key_name in({key_name_s})"
+        report_condition += f" and key_name in({key_name_s})"
         stat_report_model = StatReportModel(context=self.context)
-        behavior_report_list = stat_report_model.get_dict_list(condition, group_by="key_name", field="key_name,SUM(key_value) AS key_value",params=params)
+        behavior_report_list = stat_report_model.get_dict_list(report_condition, group_by="key_name", field="key_name,SUM(key_value) AS key_value",params=params)
         #公共映射组（未去重）
         common_groups_1 = [orm.group_name for orm in stat_orm_list]
         #公共映射组(去重)
@@ -204,7 +213,7 @@ class StatBaseModel(FrameBaseModel):
 
         return common_group_data_list
 
-    def get_trend_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False):
+    def get_trend_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False, orm_condition=None, orm_params=None):
         """
         :description: 报表数据列表(趋势图)
         :param app_id：应用标识
@@ -212,8 +221,10 @@ class StatBaseModel(FrameBaseModel):
         :param module_id：活动模块标识
         :param start_date：开始时间
         :param end_date：结束时间
-        :param order_by：排序
+        :param order_by：orm排序
         :param is_only_module：是否只取module的数据
+        :param orm_condition：orm查询条件
+        :param orm_params：orm参数数组
         :return list
         :last_editors: HuangJianYi
         """
@@ -226,9 +237,16 @@ class StatBaseModel(FrameBaseModel):
             condition += " and create_date<%s"
             params.append(end_date)
         if is_only_module == True:
-            stat_orm_list = StatOrmModel(context=self.context).get_list("act_id=%s and module_id=%s and is_show=1", order_by=order_by, params=[act_id, module_id])
+            if not orm_condition:
+                orm_condition = "act_id=%s and module_id=%s and is_show=1"
+            if not orm_params:
+                orm_params = [act_id, module_id]
         else:
-            stat_orm_list = StatOrmModel(context=self.context).get_list("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1", order_by=order_by, params=[act_id,module_id])
+            if not orm_condition:
+                orm_condition = "((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1"
+            if not orm_params:
+                orm_params = [act_id, module_id]
+        stat_orm_list = StatOrmModel(context=self.context).get_list(where=orm_condition, order_by=order_by, params=orm_params)
         if len(stat_orm_list)<=0:
             return []
         key_name_s = ','.join(["'%s'" % str(stat_orm.key_name) for stat_orm in stat_orm_list])
